@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.20 2004/07/16 10:59:57 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.21 2004/07/19 01:28:44 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -181,7 +181,7 @@ typedef struct {
 	 */
 	int auth_kind;		/* 3: clear text password, 4: crypt password, 5: md5 password */
 	int pwd_size;		/* password (sent back from frontend) size in host order */
-	char password[MAX_PASSWORD_SIZE];		/* /* password (sent back from frontend) */
+	char password[MAX_PASSWORD_SIZE];		/* password (sent back from frontend) */
 	char salt[4];		/* password salt */
 
 	/*
