@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_error.c,v 1.5 2004/07/04 03:12:42 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_error.c,v 1.6 2004/07/19 01:28:44 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -24,6 +24,8 @@
 
 #include <stdio.h>
 #include <stdarg.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "pool.h"
 
