@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.27 2004/07/19 01:23:58 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.28 2004/07/22 10:37:06 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -766,7 +766,7 @@ static POOL_STATUS AsciiRow(POOL_CONNECTION *frontend,
 		if (REPLICATION && size1 > 0 && (mask & nullmap1[i/8]))
 		{
 			/* read and discard secondary data */
-			if (pool_read2(SECONDARY(backend), size) == NULL)
+			if (pool_read2(SECONDARY(backend), size1) == NULL)
 				return POOL_END;
 		}
 
@@ -874,7 +874,7 @@ static POOL_STATUS BinaryRow(POOL_CONNECTION *frontend,
 		if (REPLICATION && size1 > 0 && (mask & nullmap1[i/8]))
 		{
 			/* read and discard secondary data */
-			if (pool_read2(SECONDARY(backend), size) == NULL)
+			if (pool_read2(SECONDARY(backend), size1) == NULL)
 				return POOL_END;
 		}
 
@@ -1294,7 +1294,7 @@ static POOL_STATUS ProcessFrontendResponse(POOL_CONNECTION *frontend,
 	char fkind;
 	POOL_STATUS status;
 
-	if (frontend->no_forward != 0)
+	if (frontend->len <= 0 && frontend->no_forward != 0)
 		return POOL_CONTINUE;
 
 	if (pool_read(frontend, &fkind, 1) < 0)
